@@ -32,16 +32,6 @@ func SetCacheDir(dir string) {
 	cacheDir = dir
 }
 
-// StringInSlice checks if strings exist in list of strings
-func StringInSlice(a string, list []string) bool {
-	for _, b := range list {
-		if b == a {
-			return true
-		}
-	}
-	return false
-}
-
 // CopyFile copies the file content from scr to dst
 func CopyFile(src, dst string) (int64, error) {
 	sourceFileStat, err := os.Stat(src)
@@ -68,7 +58,7 @@ func CopyFile(src, dst string) (int64, error) {
 	return n, err
 }
 
-// getTLSConfig get tls config from CA, Cert and Key file
+// GetTLSConfig get tls config from CA, Cert and Key file
 func GetTLSConfig(caCertPath, certPath, keyPath string) (*x509.CertPool, tls.Certificate, error) {
 	cert, err := tls.LoadX509KeyPair(certPath, keyPath)
 	if err != nil {
